#
# Changes
# 
# 2022-09, Arjo Segers, Met-Norway
#   Added cso_superob module.
#   Added cso_colocate module.
#


#-------------------------------------------------
# help
#-------------------------------------------------

"""

.. Label, use :ref:`text <label>` for reference
.. _cso-module:

**************
``cso`` module
**************

The ``cso`` module is the top level access to the various 
:ref:`CSO classes <cso-classes>` and routines.
    
Actual implementations can be found in submodules:

.. The following are names of '.rst' files in the 'doc/sources' directory ;
   this ensures that each sub-module is given a seperate page in the documentation.
    
.. toctree::
   :maxdepth: 1

   pymod-cso_file
   pymod-cso_inquire
   pymod-cso_scihub
   pymod-cso_pal
   pymod-cso_s5p
   pymod-cso_s5p_superobs
   pymod-cso_gridded
   pymod-cso_colocate
   pymod-cso_superobs
   pymod-cso_catalogue
   pymod-cso_plot
   pymod-cso_regions
   pymod-cso_constants
   pymod-cso_mapping


.. Label, use :ref:`text <label>` for reference
.. _cso-classes:

CSO classes
===========

The CSO python classes could be imported from the 
:ref:`cso module <cso-module>`,
and are defined according to the following hierchy:

* :py:class:`.UtopyaRc`

  * :py:class:`.CSO_Inquire_Plot`
  * :py:class:`.CSO_SciHub_Inquire`
  * :py:class:`.CSO_PAL_Inquire`
  * :py:class:`.CSO_S5p_Convert`
  * :py:class:`.CSO_S5p_Listing`
  * :py:class:`.CSO_GriddedAverage`
  * :py:class:`.CSO_GriddedAverageMeans`
  * :py:class:`.CSO_CoLocate`
  * :py:class:`.CSO_CoLocatePlotTimeSeries`
  * :py:class:`.CSO_SuperObs`
  * :py:class:`.CSO_CreateCountryMask`
  * :py:class:`.CSO_Catalogue`

    * :py:class:`.CSO_Catalogue`
    * :py:class:`.CSO_SimCatalogue`
    * :py:class:`.CSO_GriddedCatalogue`

  * :py:class:`.CSO_CreateCountryMask`
  * :py:class:`.CSO_CatalogueBase`

      * :py:class:`.CSO_Catalogue_RegionsMaps`
      * :py:class:`.CSO_Catalogue_RegionsTimeSeries`

  * :py:class:`.CSO_Statistics_RegionsTables`

* :py:class:`.S5p_File`
* :py:class:`.CSO_File`

  * :py:class:`.CSO_S5p_File`

* :py:class:`.CSO_Listing`
* :py:class:`.CreateCountryMap`
* :py:class:`.RegionMap`

* :py:class:`.Figure`
 
  * :py:class:`.MapFigure`
   
  * :py:class:`.ColorbarFigure`
    
    * :py:class:`.ColorbarMapFigure`

"""

#-------------------------------------------------
# imports from sub modules
#-------------------------------------------------

from cso_file         import *
from cso_inquire      import *
from cso_scihub       import *
from cso_pal          import *
from cso_s5p          import *
from cso_s5p_superobs import *
from cso_gridded      import *
from cso_colocate     import *
from cso_superobs     import *
from cso_regions      import *
from cso_constants    import *
from cso_mapping      import *
from cso_plot         import *
from cso_catalogue    import *


#-------------------------------------------------
# end
#-------------------------------------------------
